@@ -12,10 +12,11 @@ use Exporter qw/ import /;
 
 # use AutoLoader;
 use Carp;
+use File::Spec::Functions qw/ file_name_is_absolute /;
 use Module::Load 0.10;
 use Module::Loaded;
 
-our $VERSION = 'v3.0.2';
+our $VERSION = 'v3.2.0';
 
 our %EXPORT_TAGS = (
     'all'     => [qw( hex2tuple tuple2hex all_schemes )],
@@ -69,29 +70,26 @@ sub _load {
 # TODO - see if using Tie::Hash::Layered gives an improvement
 
 sub _load_scheme_from_module {
-    my $self = shift;
-    my $base = __PACKAGE__;
+    my ($self, $scheme) = @_;
+
+    my $module =
+        $scheme =~ /^\+/ ? substr( $scheme, 1 )
+      : $scheme =~ /^Color::Library::Dictionary::/ ? $scheme
+      :   __PACKAGE__ . '::' . $scheme;
 
-    my $module = join( '::', $base, ( my $scheme = shift ) );
     eval { _load($module); };
     if ($@) {
-        eval { _load( $module = $scheme ); };
-        if ($@) {
-            croak "Cannot load color naming scheme \`$module\'";
-        }
+        croak "Cannot load color naming scheme module $module";
     }
 
-    {
-        no strict 'refs';
-        if ( $module =~ $base ) {
-            $self->load_scheme( $module->NamesRgbTable );
-        }
-        elsif ( $module =~ /Color::Library::Dictionary/ ) {
-            $self->load_scheme( $module->_load_color_list );
-        }
-        else {
-            croak "Unknown scheme type: $module";
-        }
+    if ($module->can('NamesRgbTable')) {
+        $self->load_scheme( $module->NamesRgbTable );
+    }
+    elsif ($module->can('_load_color_list')) {
+        $self->load_scheme( $module->_load_color_list );
+    }
+    else {
+        croak "Unknown scheme type: $module";
     }
 }
 
@@ -109,11 +107,14 @@ sub TIEHASH {
             if ( ref $scheme ) {
                 $self->load_scheme($scheme);
             }
-            elsif ( -r $scheme ) {
+            elsif ($scheme =~ /^\+?(?:\w+[:][:])*\w+$/) {
+                $self->_load_scheme_from_module($scheme);
+            }
+            elsif ( file_name_is_absolute($scheme) ) {
                 $self->_load_scheme_from_file($scheme);
             }
             else {
-                $self->_load_scheme_from_module($scheme);
+                croak "Unknown color scheme: $scheme";
             }
         }
     }
@@ -130,12 +131,12 @@ sub FETCH {
 
     # If we're passing it an RGB value, return that value
 
-    if ( $key =~ m/^\x23?([\da-f]{6})$/ ) {
+    if ( $key =~ m/^(?:\x23|0x)?([0-9a-f]{6})$/ ) {
         return $1;
     }
     else {
 
-        $key =~ s/[^a-z\d\%]//g;    # ignore non-word characters
+        $key =~ s/[^0-9a-z\%]//g;    # ignore non-word characters
 
         my $val = undef;
         my $i   = 0;
@@ -193,7 +194,7 @@ sub load_scheme {
             my $code = $rec->[5];
             $name =~ s/[\W\_]//g;    # ignore non-word characters
             $s->{$name} = $code unless ( exists $s->{$name} );
-            if ( $key =~ /^(.+\:.+)\.(\d+)$/ ) {
+            if ( $key =~ /^(.+\:.+)\.([0-9]+)$/ ) {
                 $s->{"$name$2"} = $code;
             }
         }
@@ -381,13 +382,13 @@ Graphics::ColorNames - defines RGB values for common color names
 
 =head1 VERSION
 
-version v3.0.2
+version v3.2.0
 
 =head1 SYNOPSIS
 
   use Graphics::ColorNames 2.10;
 
-  $po = new Graphics::ColorNames(qw( X ));
+  $po = Graphics::ColorNames->new( qw[ X ] );
 
   $rgb = $po->hex('green');          # returns '00ff00'
   $rgb = $po->hex('green', '0x');    # returns '0x00ff00'
@@ -398,7 +399,7 @@ version v3.0.2
 
   $rgb = $po->green;                 # same as $po->hex('green');
 
-  tie %ph, 'Graphics::ColorNames', (qw( X ));
+  tie %ph, 'Graphics::ColorNames', (qw[ X ]);
 
   $rgb = $ph{green};                 # same as $po->hex('green');
 
@@ -417,7 +418,7 @@ For example,
 
   use GD;
 
-  $pal = new Graphics::ColorNames;
+  $pal = Graphics::ColorNames->new;
 
   $img = new GD::Image(100, 100);
 
@@ -462,10 +463,10 @@ L</SEE ALSO> for a discussion of the differences between modules).
 
 Multiple schemes can be used:
 
-  tie %pal, 'Graphics::ColorNames', qw(HTML Netscape);
+  tie %pal, 'Graphics::ColorNames', qw(HTML X);
 
-In this case, if the name is not a valid HTML color, the Netscape name
-will be used.
+In this case, if the name is not a valid HTML color, the X-windows
+name will be used.
 
 One can load all available schemes in the Graphics::ColorNames namespace
 (as of version 2.0):
@@ -489,6 +490,9 @@ The value returned is in the six-digit hexidecimal format used in HTML and
 CSS (without the initial '#'). To convert it to separate red, green, and
 blue values (between 0 and 255), use the L</hex2tuple> function.
 
+You may also specify an absolute filename as a color scheme, if the file
+is in the same format as the standard F<rgb.txt> file.
+
 =head2 Object-Oriented Interface
 
 If you prefer, an object-oriented interface is available:
@@ -596,15 +600,6 @@ duplicate names with spaces).
 names are also used with older CSS and SVG specifications. (You may
 want to see L<Graphics::ColorNames::SVG> for a complete list.)
 
-=item Netscape
-
-100 color names names associated Netscape 1.1 (I cannot determine whether
-they were once usable in Netscape or were arbitrary names for RGB values--
-many of these names are not recognized by later versions of Netscape).
-
-This scheme may be deprecated in future versions, but available as a
-separate module.
-
 =item Windows
 
 16 commom color names used with Microsoft Windows and related
@@ -613,10 +608,14 @@ although with different names.
 
 =back
 
+Note that the L<Graphics::ColorNames::Netscape> scheme is no longer
+included with this distribution. If you need it, you should install it
+separately.
+
 Rather than a color scheme, the path or open filehandle for a
 F<rgb.txt> file may be specified.
 
-Additional color schemes may be available on CPAN.
+Additional color schemes are available on CPAN.
 
 =head2 Custom Color Schemes
 
@@ -715,7 +714,7 @@ Robert Rothenberg <rrwo@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alan D. Salewski Steve Pomeroy "chemboy" "magnus" Gary Vollink
+=for stopwords Alan D. Salewski Steve Pomeroy "chemboy" Magnus Cedergren Gary Vollink Claus Färber
 
 =over 4
 
@@ -733,12 +732,16 @@ Steve Pomeroy <xavier@cpan.org>
 
 =item *
 
-"magnus" <magnus@mbox604.swipnet.se>
+Magnus Cedergren <magnus@mbox604.swipnet.se>
 
 =item *
 
 Gary Vollink <gary@vollink.com>
 
+=item *
+
+Claus Färber <cfaerber@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
