@@ -6,15 +6,8 @@ package Graphics::ColorNames::X;
 use strict;
 use warnings;
 
-our $VERSION = 'v3.0.2';
+our $VERSION = 'v3.2.0';
 
-# Original name and colors (v1.01 and earlier) from Kevin J. Walsh,
-# http://eies.njit.edu/~walsh/rgb.html
-
-# Afterwards, XConsortium: rgb.txt,v 10.41 94/02/20 18:39:36 rws Exp
-# Verified with Xorg: rgb.txt,v 1.3 2000/08/17 19:54:00 cpqbld Exp
-
-# Duplicate names with spaces were removed in v2.10.
 
 sub NamesRgbTable() {
     use integer;
@@ -56,6 +49,10 @@ sub NamesRgbTable() {
         "lightslategrey"       => 0x778899,
         "gray"                 => 0xbebebe,
         "grey"                 => 0xbebebe,
+        "x11gray"              => 0xbebebe,
+        "x11grey"              => 0xbebebe,
+        "webgray"              => 0x808080,
+        "webgrey"              => 0x808080,
         "lightgrey"            => 0xd3d3d3,
         "lightgray"            => 0xd3d3d3,
         "midnightblue"         => 0x191970,
@@ -82,6 +79,7 @@ sub NamesRgbTable() {
         "mediumturquoise"      => 0x48d1cc,
         "turquoise"            => 0x40e0d0,
         "cyan"                 => 0x00ffff,
+        "aqua"                 => 0x00ffff,
         "lightcyan"            => 0xe0ffff,
         "cadetblue"            => 0x5f9ea0,
         "mediumaquamarine"     => 0x66cdaa,
@@ -96,6 +94,9 @@ sub NamesRgbTable() {
         "springgreen"          => 0x00ff7f,
         "lawngreen"            => 0x7cfc00,
         "green"                => 0x00ff00,
+        "lime"                 => 0x00ff00,
+        "x11green"             => 0x00ff00,
+        "webgreen"             => 0x008000,
         "chartreuse"           => 0x7fff00,
         "mediumspringgreen"    => 0x00fa9a,
         "greenyellow"          => 0xadff2f,
@@ -142,9 +143,12 @@ sub NamesRgbTable() {
         "lightpink"            => 0xffb6c1,
         "palevioletred"        => 0xdb7093,
         "maroon"               => 0xb03060,
+        "x11maroon"            => 0xb03060,
+        "webmaroon"            => 0x800000,
         "mediumvioletred"      => 0xc71585,
         "violetred"            => 0xd02090,
         "magenta"              => 0xff00ff,
+        "fuchsia"              => 0xff00ff,
         "violet"               => 0xee82ee,
         "plum"                 => 0xdda0dd,
         "orchid"               => 0xda70d6,
@@ -153,6 +157,8 @@ sub NamesRgbTable() {
         "darkviolet"           => 0x9400d3,
         "blueviolet"           => 0x8a2be2,
         "purple"               => 0xa020f0,
+        "x11purple"            => 0xa020f0,
+        "webpurple"            => 0x800080,
         "mediumpurple"         => 0x9370db,
         "thistle"              => 0xd8bfd8,
         "snow1"                => 0xfffafa,
@@ -243,10 +249,6 @@ sub NamesRgbTable() {
         "slategray2"           => 0xb9d3ee,
         "slategray3"           => 0x9fb6cd,
         "slategray4"           => 0x6c7b8b,
-        "slategrey1"           => 0xc6e2ff,
-        "slategrey2"           => 0xb9d3ee,
-        "slategrey3"           => 0x9fb6cd,
-        "slategrey4"           => 0x6c7b8b,
         "lightsteelblue1"      => 0xcae1ff,
         "lightsteelblue2"      => 0xbcd2ee,
         "lightsteelblue3"      => 0xa2b5cd,
@@ -279,10 +281,6 @@ sub NamesRgbTable() {
         "darkslategray2"       => 0x8deeee,
         "darkslategray3"       => 0x79cdcd,
         "darkslategray4"       => 0x528b8b,
-        "darkslategrey1"       => 0x97ffff,
-        "darkslategrey2"       => 0x8deeee,
-        "darkslategrey3"       => 0x79cdcd,
-        "darkslategrey4"       => 0x528b8b,
         "aquamarine1"          => 0x7fffd4,
         "aquamarine2"          => 0x76eec6,
         "aquamarine3"          => 0x66cdaa,
@@ -476,206 +474,206 @@ sub NamesRgbTable() {
         "thistle3"             => 0xcdb5cd,
         "thistle4"             => 0x8b7b8b,
         "gray0"                => 0x000000,
-        "gray1"                => 0x030303,
-        "gray2"                => 0x050505,
-        "gray3"                => 0x080808,
-        "gray4"                => 0x0a0a0a,
-        "gray5"                => 0x0d0d0d,
-        "gray6"                => 0x0f0f0f,
-        "gray7"                => 0x121212,
-        "gray8"                => 0x141414,
-        "gray9"                => 0x171717,
-        "gray10"               => 0x1a1a1a,
-        "gray11"               => 0x1c1c1c,
-        "gray12"               => 0x1f1f1f,
-        "gray13"               => 0x212121,
-        "gray14"               => 0x242424,
-        "gray15"               => 0x262626,
-        "gray16"               => 0x292929,
-        "gray17"               => 0x2b2b2b,
-        "gray18"               => 0x2e2e2e,
-        "gray19"               => 0x303030,
-        "gray20"               => 0x333333,
-        "gray21"               => 0x363636,
-        "gray22"               => 0x383838,
-        "gray23"               => 0x3b3b3b,
-        "gray24"               => 0x3d3d3d,
-        "gray25"               => 0x404040,
-        "gray26"               => 0x424242,
-        "gray27"               => 0x454545,
-        "gray28"               => 0x474747,
-        "gray29"               => 0x4a4a4a,
-        "gray30"               => 0x4d4d4d,
-        "gray31"               => 0x4f4f4f,
-        "gray32"               => 0x525252,
-        "gray33"               => 0x545454,
-        "gray34"               => 0x575757,
-        "gray35"               => 0x595959,
-        "gray36"               => 0x5c5c5c,
-        "gray37"               => 0x5e5e5e,
-        "gray38"               => 0x616161,
-        "gray39"               => 0x636363,
-        "gray40"               => 0x666666,
-        "gray41"               => 0x696969,
-        "gray42"               => 0x6b6b6b,
-        "gray43"               => 0x6e6e6e,
-        "gray44"               => 0x707070,
-        "gray45"               => 0x737373,
-        "gray46"               => 0x757575,
-        "gray47"               => 0x787878,
-        "gray48"               => 0x7a7a7a,
-        "gray49"               => 0x7d7d7d,
-        "gray50"               => 0x7f7f7f,
-        "gray51"               => 0x828282,
-        "gray52"               => 0x858585,
-        "gray53"               => 0x878787,
-        "gray54"               => 0x8a8a8a,
-        "gray55"               => 0x8c8c8c,
-        "gray56"               => 0x8f8f8f,
-        "gray57"               => 0x919191,
-        "gray58"               => 0x949494,
-        "gray59"               => 0x969696,
-        "gray60"               => 0x999999,
-        "gray61"               => 0x9c9c9c,
-        "gray62"               => 0x9e9e9e,
-        "gray63"               => 0xa1a1a1,
-        "gray64"               => 0xa3a3a3,
-        "gray65"               => 0xa6a6a6,
-        "gray66"               => 0xa8a8a8,
-        "gray67"               => 0xababab,
-        "gray68"               => 0xadadad,
-        "gray69"               => 0xb0b0b0,
-        "gray70"               => 0xb3b3b3,
-        "gray71"               => 0xb5b5b5,
-        "gray72"               => 0xb8b8b8,
-        "gray73"               => 0xbababa,
-        "gray74"               => 0xbdbdbd,
-        "gray75"               => 0xbfbfbf,
-        "gray76"               => 0xc2c2c2,
-        "gray77"               => 0xc4c4c4,
-        "gray78"               => 0xc7c7c7,
-        "gray79"               => 0xc9c9c9,
-        "gray80"               => 0xcccccc,
-        "gray81"               => 0xcfcfcf,
-        "gray82"               => 0xd1d1d1,
-        "gray83"               => 0xd4d4d4,
-        "gray84"               => 0xd6d6d6,
-        "gray85"               => 0xd9d9d9,
-        "gray86"               => 0xdbdbdb,
-        "gray87"               => 0xdedede,
-        "gray88"               => 0xe0e0e0,
-        "gray89"               => 0xe3e3e3,
-        "gray90"               => 0xe5e5e5,
-        "gray91"               => 0xe8e8e8,
-        "gray92"               => 0xebebeb,
-        "gray93"               => 0xededed,
-        "gray94"               => 0xf0f0f0,
-        "gray95"               => 0xf2f2f2,
-        "gray96"               => 0xf5f5f5,
-        "gray97"               => 0xf7f7f7,
-        "gray98"               => 0xfafafa,
-        "gray99"               => 0xfcfcfc,
-        "gray100"              => 0xffffff,
         "grey0"                => 0x000000,
+        "gray1"                => 0x030303,
         "grey1"                => 0x030303,
+        "gray2"                => 0x050505,
         "grey2"                => 0x050505,
+        "gray3"                => 0x080808,
         "grey3"                => 0x080808,
+        "gray4"                => 0x0a0a0a,
         "grey4"                => 0x0a0a0a,
+        "gray5"                => 0x0d0d0d,
         "grey5"                => 0x0d0d0d,
+        "gray6"                => 0x0f0f0f,
         "grey6"                => 0x0f0f0f,
+        "gray7"                => 0x121212,
         "grey7"                => 0x121212,
+        "gray8"                => 0x141414,
         "grey8"                => 0x141414,
+        "gray9"                => 0x171717,
         "grey9"                => 0x171717,
+        "gray10"               => 0x1a1a1a,
         "grey10"               => 0x1a1a1a,
+        "gray11"               => 0x1c1c1c,
         "grey11"               => 0x1c1c1c,
+        "gray12"               => 0x1f1f1f,
         "grey12"               => 0x1f1f1f,
+        "gray13"               => 0x212121,
         "grey13"               => 0x212121,
+        "gray14"               => 0x242424,
         "grey14"               => 0x242424,
+        "gray15"               => 0x262626,
         "grey15"               => 0x262626,
+        "gray16"               => 0x292929,
         "grey16"               => 0x292929,
+        "gray17"               => 0x2b2b2b,
         "grey17"               => 0x2b2b2b,
+        "gray18"               => 0x2e2e2e,
         "grey18"               => 0x2e2e2e,
+        "gray19"               => 0x303030,
         "grey19"               => 0x303030,
+        "gray20"               => 0x333333,
         "grey20"               => 0x333333,
+        "gray21"               => 0x363636,
         "grey21"               => 0x363636,
+        "gray22"               => 0x383838,
         "grey22"               => 0x383838,
+        "gray23"               => 0x3b3b3b,
         "grey23"               => 0x3b3b3b,
+        "gray24"               => 0x3d3d3d,
         "grey24"               => 0x3d3d3d,
+        "gray25"               => 0x404040,
         "grey25"               => 0x404040,
+        "gray26"               => 0x424242,
         "grey26"               => 0x424242,
+        "gray27"               => 0x454545,
         "grey27"               => 0x454545,
+        "gray28"               => 0x474747,
         "grey28"               => 0x474747,
+        "gray29"               => 0x4a4a4a,
         "grey29"               => 0x4a4a4a,
+        "gray30"               => 0x4d4d4d,
         "grey30"               => 0x4d4d4d,
+        "gray31"               => 0x4f4f4f,
         "grey31"               => 0x4f4f4f,
+        "gray32"               => 0x525252,
         "grey32"               => 0x525252,
+        "gray33"               => 0x545454,
         "grey33"               => 0x545454,
+        "gray34"               => 0x575757,
         "grey34"               => 0x575757,
+        "gray35"               => 0x595959,
         "grey35"               => 0x595959,
+        "gray36"               => 0x5c5c5c,
         "grey36"               => 0x5c5c5c,
+        "gray37"               => 0x5e5e5e,
         "grey37"               => 0x5e5e5e,
+        "gray38"               => 0x616161,
         "grey38"               => 0x616161,
+        "gray39"               => 0x636363,
         "grey39"               => 0x636363,
+        "gray40"               => 0x666666,
         "grey40"               => 0x666666,
+        "gray41"               => 0x696969,
         "grey41"               => 0x696969,
+        "gray42"               => 0x6b6b6b,
         "grey42"               => 0x6b6b6b,
+        "gray43"               => 0x6e6e6e,
         "grey43"               => 0x6e6e6e,
+        "gray44"               => 0x707070,
         "grey44"               => 0x707070,
+        "gray45"               => 0x737373,
         "grey45"               => 0x737373,
+        "gray46"               => 0x757575,
         "grey46"               => 0x757575,
+        "gray47"               => 0x787878,
         "grey47"               => 0x787878,
+        "gray48"               => 0x7a7a7a,
         "grey48"               => 0x7a7a7a,
+        "gray49"               => 0x7d7d7d,
         "grey49"               => 0x7d7d7d,
+        "gray50"               => 0x7f7f7f,
         "grey50"               => 0x7f7f7f,
+        "gray51"               => 0x828282,
         "grey51"               => 0x828282,
+        "gray52"               => 0x858585,
         "grey52"               => 0x858585,
+        "gray53"               => 0x878787,
         "grey53"               => 0x878787,
+        "gray54"               => 0x8a8a8a,
         "grey54"               => 0x8a8a8a,
+        "gray55"               => 0x8c8c8c,
         "grey55"               => 0x8c8c8c,
+        "gray56"               => 0x8f8f8f,
         "grey56"               => 0x8f8f8f,
+        "gray57"               => 0x919191,
         "grey57"               => 0x919191,
+        "gray58"               => 0x949494,
         "grey58"               => 0x949494,
+        "gray59"               => 0x969696,
         "grey59"               => 0x969696,
+        "gray60"               => 0x999999,
         "grey60"               => 0x999999,
+        "gray61"               => 0x9c9c9c,
         "grey61"               => 0x9c9c9c,
+        "gray62"               => 0x9e9e9e,
         "grey62"               => 0x9e9e9e,
+        "gray63"               => 0xa1a1a1,
         "grey63"               => 0xa1a1a1,
+        "gray64"               => 0xa3a3a3,
         "grey64"               => 0xa3a3a3,
+        "gray65"               => 0xa6a6a6,
         "grey65"               => 0xa6a6a6,
+        "gray66"               => 0xa8a8a8,
         "grey66"               => 0xa8a8a8,
+        "gray67"               => 0xababab,
         "grey67"               => 0xababab,
+        "gray68"               => 0xadadad,
         "grey68"               => 0xadadad,
+        "gray69"               => 0xb0b0b0,
         "grey69"               => 0xb0b0b0,
+        "gray70"               => 0xb3b3b3,
         "grey70"               => 0xb3b3b3,
+        "gray71"               => 0xb5b5b5,
         "grey71"               => 0xb5b5b5,
+        "gray72"               => 0xb8b8b8,
         "grey72"               => 0xb8b8b8,
+        "gray73"               => 0xbababa,
         "grey73"               => 0xbababa,
+        "gray74"               => 0xbdbdbd,
         "grey74"               => 0xbdbdbd,
+        "gray75"               => 0xbfbfbf,
         "grey75"               => 0xbfbfbf,
+        "gray76"               => 0xc2c2c2,
         "grey76"               => 0xc2c2c2,
+        "gray77"               => 0xc4c4c4,
         "grey77"               => 0xc4c4c4,
+        "gray78"               => 0xc7c7c7,
         "grey78"               => 0xc7c7c7,
+        "gray79"               => 0xc9c9c9,
         "grey79"               => 0xc9c9c9,
+        "gray80"               => 0xcccccc,
         "grey80"               => 0xcccccc,
+        "gray81"               => 0xcfcfcf,
         "grey81"               => 0xcfcfcf,
+        "gray82"               => 0xd1d1d1,
         "grey82"               => 0xd1d1d1,
+        "gray83"               => 0xd4d4d4,
         "grey83"               => 0xd4d4d4,
+        "gray84"               => 0xd6d6d6,
         "grey84"               => 0xd6d6d6,
+        "gray85"               => 0xd9d9d9,
         "grey85"               => 0xd9d9d9,
+        "gray86"               => 0xdbdbdb,
         "grey86"               => 0xdbdbdb,
+        "gray87"               => 0xdedede,
         "grey87"               => 0xdedede,
+        "gray88"               => 0xe0e0e0,
         "grey88"               => 0xe0e0e0,
+        "gray89"               => 0xe3e3e3,
         "grey89"               => 0xe3e3e3,
+        "gray90"               => 0xe5e5e5,
         "grey90"               => 0xe5e5e5,
+        "gray91"               => 0xe8e8e8,
         "grey91"               => 0xe8e8e8,
+        "gray92"               => 0xebebeb,
         "grey92"               => 0xebebeb,
+        "gray93"               => 0xededed,
         "grey93"               => 0xededed,
+        "gray94"               => 0xf0f0f0,
         "grey94"               => 0xf0f0f0,
+        "gray95"               => 0xf2f2f2,
         "grey95"               => 0xf2f2f2,
+        "gray96"               => 0xf5f5f5,
         "grey96"               => 0xf5f5f5,
+        "gray97"               => 0xf7f7f7,
         "grey97"               => 0xf7f7f7,
+        "gray98"               => 0xfafafa,
         "grey98"               => 0xfafafa,
+        "gray99"               => 0xfcfcfc,
         "grey99"               => 0xfcfcfc,
+        "gray100"              => 0xffffff,
         "grey100"              => 0xffffff,
         "darkgrey"             => 0xa9a9a9,
         "darkgray"             => 0xa9a9a9,
@@ -684,6 +682,12 @@ sub NamesRgbTable() {
         "darkmagenta"          => 0x8b008b,
         "darkred"              => 0x8b0000,
         "lightgreen"           => 0x90ee90,
+        "crimson"              => 0xdc143c,
+        "indigo"               => 0x4b0082,
+        "olive"                => 0x808000,
+        "rebeccapurple"        => 0x663399,
+        "silver"               => 0xc0c0c0,
+        "teal"                 => 0x008080,
     };
 }
 
@@ -701,7 +705,7 @@ Graphics::ColorNames::X - X-Windows color names and equivalent RGB values
 
 =head1 VERSION
 
-version v3.0.2
+version v3.2.0
 
 =head1 SYNOPSIS
 
@@ -713,11 +717,18 @@ version v3.0.2
 =head1 DESCRIPTION
 
 This module defines color names and their associated RGB values used in
-X-Windows (from the X-Windows C<rgb.txt> file).
+X-Windows.
+
+It is based on the 2014 version of the F<rgb.txt> file, whcih includes
+colors from CSS4.
 
 =head1 SEE ALSO
 
-L<Graphics::ColorNames>, F<rgb.txt>
+L<Graphics::ColorNames>
+
+L<Graphics::ColorNames::CSS>
+
+L<rgb.txt|https://cgit.freedesktop.org/xorg/app/rgb/plain/rgb.txt>
 
 =head1 SOURCE
 
